package controller

import (
	"github.com/gofiber/fiber/v2"
	"github.com/gofiber/swagger"
	"gofiber.study.skcks.cn/common/errorx"
	"gofiber.study.skcks.cn/common/logger"
	"gofiber.study.skcks.cn/common/response"
	"gofiber.study.skcks.cn/controller/user"
)

func RegisterController(app *fiber.App) {
	user.RegisterController(app)
}

// HelloWorld
//
// @Summary      HelloWorld
// @Description  简单的 HelloWorld 示例
// @Tags         HelloWorld
// @Accept       json
// @Produce      json
// @Success      200  {object}  response.Response{data=string}
// @Failure	     default {object}  errorx.CodeErrorResponse
// @Router       / [get]
func HelloWorld(app *fiber.App) {
	app.Get("/", func(c *fiber.Ctx) error {
		logger.Log.Infof("\n%s", c.Request().String())
		return c.JSON(response.NewResponse("Hello, World 👋!"))
	})
}

// ErrorHandler
//
// @Summary      错误处理
// @Description  错误信息示例
// @Tags         Error
// @Accept       json
// @Produce      json
// @Failure	     default {object}  errorx.CodeErrorResponse
// @Router       /error [get]
// @Router       /error [post]
// @Router       /error [put]
// @Router       /error [delete]
// @Router       /error [patch]
func ErrorHandler(app *fiber.App) {
	app.All("/error", func(ctx *fiber.Ctx) error {
		return ctx.JSON(errorx.NewDefaultError("错误信息示例"))
	})
}

func SwaggerHandler(app *fiber.App) {
	app.Get("/swagger/*", swagger.New(swagger.Config{
		DeepLinking: false,
		// Expand ("list") or Collapse ("none") tag groups by default
		DocExpansion: "list",
	}))
}
